ComponentModelTester<CM extends ComponentModel<C, M> , C extends ElementaryComponent<IComponentModel> , M extends ElementaryModel> class
abstract
Controls ComponentModel lifecycle during tests (Jaspr analogue of Flutter
Elementary’s WMTester from package elementary_test).
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activate(
) → void -
Emulates
Element.activatefor the model. -
deactivate(
) → void -
Emulates
Element.deactivatefor the model. -
didChangeDependencies(
) → void -
Emulates
Element.didChangeDependenciesfor the model. -
handleError(
Object error) → void -
Emulates
ComponentModel.onErrorHandleviaComponentModel.handleTestError. -
init(
{C? initComponent}) → void -
Attaches
BuildContext, optional component, thenComponentModel.initComponentModelandComponentModel.didChangeDependencies(same order asElementaryElement.mount). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unmount(
) → void -
Emulates permanent removal:
ComponentModel.disposeand clears test element/component. -
update(
C newComponent) → void -
Emulates a new
ElementaryComponentconfiguration for the same model.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited